## DDD for Python  

This is a framework for developing apps based on domain-driven design principles.
  
The design is inspired by Eric Evans theory on DDD, Vaughn Vernon's reference implementation in Java and on the Django framework.
  
### Theory:  
  
If you are new to DDD, the following sources are recommended:
  
- [Domain-Driven Design: Tackling Complexity in the Heart of Software (Eric Evans)](https://www.amazon.com/Domain-Driven-Design-Tackling-Complexity-Software/dp/0321125215)  
- [Implementing Domain-Driven Design - Vaughn Vernon](https://www.amazon.com/Implementing-Domain-Driven-Design-Vaughn-Vernon/dp/0321834577)  
  
### Installation:  
  
```bash
$ pip install ddd-for-python
```
  
### Examples:  
  
The examples are coming shortly.  
  
### Documentation:  
  
The documentation is coming shortly.
  
### Change Log:  

| | | |  
|-|-|-|  
| __Date__   | __Version__ | __Changes__                                                              |  
| 2021-03-15 | 0.9.2       | Fix bug where env file wasn't loaded.                                    |
| 2021-03-14 | 0.9.1       | Initial release.                                                         |
